Remove unused but set variable from prims_ll128.h (#1257)
Allows `-Wunused-but-set-variable` to pass
[ROCm/rccl commit: 86a4ad6e8b]
This commit is contained in:
@@ -382,7 +382,6 @@ private:
|
|||||||
|
|
||||||
T const *srcPtr = srcs[0];
|
T const *srcPtr = srcs[0];
|
||||||
T *dstPtr = dsts[0];
|
T *dstPtr = dsts[0];
|
||||||
int wireOffset = WireWordPerSlice*warp + 2*wid;
|
|
||||||
const int nwarps = nthreads/WARP_SIZE;
|
const int nwarps = nthreads/WARP_SIZE;
|
||||||
nelem = nelem < 0 ? 0 : nelem;
|
nelem = nelem < 0 ? 0 : nelem;
|
||||||
|
|
||||||
@@ -438,7 +437,6 @@ private:
|
|||||||
}
|
}
|
||||||
}
|
}
|
||||||
|
|
||||||
wireOffset += WireWordPerSlice*nwarps;
|
|
||||||
srcPtr += DataEltPerSlice*nwarps;
|
srcPtr += DataEltPerSlice*nwarps;
|
||||||
dstPtr += DataEltPerSlice*nwarps;
|
dstPtr += DataEltPerSlice*nwarps;
|
||||||
if (MULTISRCS){
|
if (MULTISRCS){
|
||||||
@@ -580,4 +578,4 @@ public:
|
|||||||
__device__ void localCopy(T* srcs, T* dsts, int eltN) {
|
__device__ void localCopy(T* srcs, T* dsts, int eltN) {
|
||||||
return mscclGenericOp<0,1,0,0>(&srcs, 1, &dsts, 1, eltN);
|
return mscclGenericOp<0,1,0,0>(&srcs, 1, &dsts, 1, eltN);
|
||||||
}
|
}
|
||||||
};
|
};
|
||||||
|
|||||||
Reference in New Issue
Block a user